@@ -3,10 +3,9 @@ package main
 import (
 	"os"
 
-	"github.com/sirupsen/logrus"
-	"github.com/suzuki-shunsuke/logrus-error/logerr"
+	"github.com/suzuki-shunsuke/slog-error/slogerr"
+	"github.com/suzuki-shunsuke/slog-util/slogutil"
 	"github.com/suzuki-shunsuke/tfmv/pkg/cli"
-	"github.com/suzuki-shunsuke/tfmv/pkg/log"
 )
 
 var (
@@ -16,13 +15,16 @@ var (
 )
 
 func main() {
-	logE := log.New(version)
-	if err := core(logE); err != nil {
-		logerr.WithError(logE, err).Fatal("tfmv failed")
+	if code := core(); code != 0 {
+		os.Exit(code)
 	}
 }
 
-func core(logE *logrus.Entry) error {
+func core() int {
+	logger := slogutil.New(&slogutil.InputNew{
+		Name:    "tfmv",
+		Version: version,
+	})
 	runner := cli.Runner{
 		Stdin:  os.Stdin,
 		Stdout: os.Stdout,
@@ -32,7 +34,11 @@ func core(logE *logrus.Entry) error {
 			Commit:  commit,
 			Date:    date,
 		},
-		LogE: logE,
+		Logger: logger,
 	}
-	return runner.Run() //nolint:wrapcheck
+	if err := runner.Run(); err != nil {
+		slogerr.WithError(logger.Logger, err).Error("tfmv failed")
+		return 1
+	}
+	return 0
 }
