@@ -4,16 +4,16 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"log/slog"
 	"path/filepath"
 	"regexp"
 	"strings"
 
-	"github.com/sirupsen/logrus"
 	"github.com/spf13/afero"
 	flag "github.com/spf13/pflag"
+	"github.com/suzuki-shunsuke/slog-util/slogutil"
 	"github.com/suzuki-shunsuke/tfmv/pkg/controller"
-	"github.com/suzuki-shunsuke/tfmv/pkg/log"
-	"github.com/suzuki-shunsuke/tfmv/pkg/types"
+	"github.com/suzuki-shunsuke/tfmv/pkg/domain"
 )
 
 const help = `tfmv - Rename Terraform resources, data sources, and modules and generate moved blocks.
@@ -39,11 +39,12 @@ Options:
 	--moved, -m      A file name where moved blocks are written. If this is "same", the file is same with renamed resources`
 
 type Runner struct {
-	Stdin   io.Reader
-	Stdout  io.Writer
-	Stderr  io.Writer
-	LDFlags *LDFlags
-	LogE    *logrus.Entry
+	Stdin       io.Reader
+	Stdout      io.Writer
+	Stderr      io.Writer
+	LDFlags     *LDFlags
+	Logger      *slogutil.Logger
+	LogLevelVar *slog.LevelVar
 }
 
 type LDFlags struct {
@@ -63,8 +64,12 @@ func (r *Runner) Run() error {
 		fmt.Fprintln(r.Stdout, help)
 		return nil
 	}
-	log.SetColor(flg.LogColor, r.LogE)
-	log.SetLevel(flg.LogLevel, r.LogE)
+	if err := r.Logger.SetLevel(flg.LogLevel); err != nil {
+		return fmt.Errorf("set log level: %w", err)
+	}
+	if err := r.Logger.SetColor(flg.LogColor); err != nil {
+		return fmt.Errorf("set log color: %w", err)
+	}
 	if flg.Moved != "same" {
 		if !strings.HasSuffix(flg.Moved, ".tf") {
 			return errors.New("--moved name must be either 'same' or a file name with the suffix .tf")
@@ -86,7 +91,7 @@ func (r *Runner) Run() error {
 
 	ctrl := &controller.Controller{}
 	ctrl.Init(afero.NewOsFs(), r.Stdout, r.Stderr)
-	return ctrl.Run(r.LogE, &types.Input{ //nolint:wrapcheck
+	return ctrl.Run(r.Logger.Logger, &domain.Input{ //nolint:wrapcheck
 		Jsonnet:   flg.Jsonnet,
 		MovedFile: flg.Moved,
 		Recursive: flg.Recursive,
