@@ -2,24 +2,24 @@ package rename
 
 import (
 	"errors"
+	"log/slog"
 
-	"github.com/sirupsen/logrus"
 	"github.com/spf13/afero"
-	"github.com/suzuki-shunsuke/tfmv/pkg/types"
+	"github.com/suzuki-shunsuke/tfmv/pkg/domain"
 )
 
 // Renamer is an interface to rename a block address.
 type Renamer interface {
-	Rename(block *types.Block) (string, error)
+	Rename(block *domain.Block) (string, error)
 }
 
 // New creates a Renamer.
-func New(logE *logrus.Entry, fs afero.Fs, input *types.Input) (Renamer, error) {
+func New(logger *slog.Logger, fs afero.Fs, input *domain.Input) (Renamer, error) {
 	if input.Replace != "" {
 		return NewReplaceRenamer(input.Replace)
 	}
 	if input.Jsonnet != "" {
-		return NewJsonnetRenamer(logE, fs, input.Jsonnet)
+		return NewJsonnetRenamer(logger, fs, input.Jsonnet)
 	}
 	if input.Regexp != "" {
 		return NewRegexpRenamer(input.Regexp)
