@@ -5,7 +5,7 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/suzuki-shunsuke/tfmv/pkg/types"
+	"github.com/suzuki-shunsuke/tfmv/pkg/domain"
 )
 
 // RegexpRenamer is a Renamer which renames addresses by replacing a regular expression `regexp` to `new`.
@@ -28,6 +28,6 @@ func NewRegexpRenamer(s string) (*RegexpRenamer, error) {
 }
 
 // Rename renames a block address.
-func (r *RegexpRenamer) Rename(block *types.Block) (string, error) {
+func (r *RegexpRenamer) Rename(block *domain.Block) (string, error) {
 	return r.regexp.ReplaceAllString(block.Name, r.new), nil
 }
