@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/suzuki-shunsuke/tfmv/pkg/types"
+	"github.com/suzuki-shunsuke/tfmv/pkg/domain"
 )
 
 // ReplaceRenamer is a Renamer which renames addresses by replacing a fixed string `old` to `new`.
@@ -24,6 +24,6 @@ func NewReplaceRenamer(s string) (*ReplaceRenamer, error) {
 }
 
 // Rename renames a block address.
-func (r *ReplaceRenamer) Rename(block *types.Block) (string, error) {
+func (r *ReplaceRenamer) Rename(block *domain.Block) (string, error) {
 	return strings.ReplaceAll(block.Name, r.old, r.new), nil
 }
